@@ -125,7 +125,7 @@ class BEDFile(GenericParser) :
             else :
                 if max_fam2_cnt < k_len :
                     max_fam2_cnt = k_len
-                    max_fam2 = k
+                    max_fam2_cnt = k
         if max_fam1_cnt > 2.5 * max_fam2_cnt :
             w = 1.0/len(famlist[max_fam1])
             return famlist[max_fam1],w
@@ -144,7 +144,7 @@ class BEDFile(GenericParser) :
     def libsize(self):
         return self.size
     
-    def build_fwtrack (self):
+    def build_fwtrack (self,temode):
 
         fwtrack = FWTrackII(filename=self.__srcfile)
         i = 0
@@ -189,6 +189,8 @@ class BEDFile(GenericParser) :
                 if len(items) > 6 : #there is weight assigned to each alignment
                     w = float(items[6])
                 #    self.size += w 
+                    if temode == 'uniq' and w < 1.0 :
+                       continue
                     fwtrack.add_loc(chrname,start,strand,w)
                     
                 else :  
@@ -202,9 +204,10 @@ class BEDFile(GenericParser) :
                     if pre_seq_name == items[3] :
                         multi_reads.append(r)
                     else :
-                        w = 1.0/len(multi_reads)
-                        for read in multi_reads :
-                            fwtrack.add_loc(read.chrom,read.start,read.strand,w)
+                        if (temode =='uniq' and len(multi_reads) ==1) or (temode =='multi') :
+                            w = 1.0/len(multi_reads)
+                            for read in multi_reads :
+                                fwtrack.add_loc(read.chrom,read.start,read.strand,w)
                             #self.size
                         multi_reads = []
                         pre_seq_name = items[3]
@@ -214,12 +217,13 @@ class BEDFile(GenericParser) :
                #     logging.warn("Unspecified chromosome name at %s line: %s. Skip!\n" %(self.__srcfile,line))
             
             if len(multi_reads) > 0 :
+              if (temode =='uniq' and len(multi_reads) ==1) or (temode =='multi') :
                 
-              w = float(1.0/len(multi_reads))
-              for k in range(len(multi_reads)) :
-                read = multi_reads[k]
+                  w = float(1.0/len(multi_reads))
+                  for k in range(len(multi_reads)) :
+                     read = multi_reads[k]
                 
-                fwtrack.add_loc(read.chrom,read.start,read.strand,w)
+                     fwtrack.add_loc(read.chrom,read.start,read.strand,w)
                          
             f.close()               
         if seq_len_count > 0 :
@@ -517,7 +521,7 @@ class BAMFile(GenericParser) :
             else :
                 if max_fam2_cnt < k_len :
                     max_fam2_cnt = k_len
-                    max_fam2 = k
+                    max_fam2_cnt = k
         
         if max_fam1_cnt > 2.5 * max_fam2_cnt :
             w = 1.0/len(famlist[max_fam1])
@@ -531,7 +535,7 @@ class BAMFile(GenericParser) :
     def builtAready (self):
         return self.__buildAready
 
-    def build_fwtrack (self):
+    def build_fwtrack (self,temode):
         """Build FWTrackII from all lines, return a FWTrackII object.
 
         Note only the unique match for a tag is kept.
@@ -599,10 +603,11 @@ class BAMFile(GenericParser) :
                     multi_reads.append(r)
                 else :
                     if prev_seq != "" :
-                        w = round(1.0/len(multi_reads),2)
-                        for k in range(len(multi_reads)) :
-                            rr = multi_reads[k]
-                            fwtrack.add_loc(rr.chrom,rr.start,rr.strand,w)
+                        if (temode == 'uniq' and len(multi_reads) == 1)  or temode == 'multi':
+                            w = round(1.0/len(multi_reads),2)
+                            for k in range(len(multi_reads)) :
+                                rr = multi_reads[k]
+                                fwtrack.add_loc(rr.chrom,rr.start,rr.strand,w)
                             
                     multi_reads = []
                     prev_seq = seq_name
@@ -623,10 +628,11 @@ class BAMFile(GenericParser) :
         
         
         if len(multi_reads) > 0 :
-            w = round(1.0/len(multi_reads),2)
-            for k in range(len(multi_reads)) :
-                rr = multi_reads[k]
-                fwtrack.add_loc(rr.chrom,rr.start,rr.strand,w)
+            if (temode == 'uniq' and len(multi_reads) == 1)  or temode == 'multi':
+                w = round(1.0/len(multi_reads),2)
+                for k in range(len(multi_reads)) :
+                    rr = multi_reads[k]
+                    fwtrack.add_loc(rr.chrom,rr.start,rr.strand,w)
                  
                                 
         self.fhd.close()
